@@ -1,13 +1,9 @@
 #ifndef COMMON_H
 #define COMMON_H
 
-#ifdef __FreeBSD__
-#define stat64 stat
-#define lstat64 lstat
-#ifdef ENABLE_FANOTIFY
+#if defined(__FreeBSD__) && defined(ENABLE_FANOTIFY)
 #error "FreeBSD does not support fanotify"
 #endif
-#endif
 
 #include <stdbool.h>
 
@@ -32,12 +28,15 @@
 void print_event_descriptions();
 int isdir(char const *path);
 
-typedef struct {
-	char const** watch_files;
-	char const** exclude_files;
-} FileList;
+struct FileList {
+	char const** watch_files_;
+	char const** exclude_files_;
+	int argc_;
+	char** argv_;
 
-void free_list(int argc, char** argv, FileList* list);
+	FileList(int argc, char** argv);
+	~FileList();
+};
 
 void construct_path_list(int argc,
 			 char** argv,
@@ -46,6 +45,6 @@ void construct_path_list(int argc,
 
 void warn_inotify_init_error(int fanotify);
 
-bool is_timeout_option_valid(unsigned int* timeout, char* o);
+bool is_timeout_option_valid(long* timeout, char* o);
 
 #endif
